@@ -6,12 +6,14 @@ var cssQuery = function() {
     // All public interfaces are showing alert instead of doing the realthing.
     // Deep compatibiliy isn't going to be implemented.
     var msg = "This implementation of cssQuery is really a wrapper to jQuery. No compatibility is ensured. Please use jQuery instead.";
-
+    var warned = 0;
     cssQuery.toString = function() {
         return "function() { [" + msg +  "] }";
     };
 
      cssQuery.clearCache = cssQuery.addModule = cssQuery.valueOf = function() {
+        if (warned) return;
+        ++warned;
         alert(msg);
     };
 
